@@ -9,7 +9,7 @@ describe Maven::Tools::POM do
       it "should convert #{dir}" do
         pom = Maven::Tools::POM.new( dir )
         file = File.join( dir, 'pom.xml' )
-        file = File.join( File.dirname( dir ), 'pom.xml' ) unless File.exists? file
+        file = File.join( File.dirname( dir ), 'pom.xml' ) unless File.exist? file
         pom_xml = File.read( file )
         pom_xml.sub!( /<!--(.|\n)*-->\n/, '' )
         pom_xml.sub!( /<?.*?>\n/, '' )
@@ -18,7 +18,7 @@ describe Maven::Tools::POM do
         pom_xml.gsub!( /tesla-polyglot/, 'polyglot' )
         pom_xml.gsub!( /${tesla.version}/, Maven::Tools::VERSIONS[ :polyglot_version ] )
 
-        pom.to_s.must_equal pom_xml
+        _(pom.to_s).must_equal pom_xml
       end
     end
   end
